from z8ter.endpoints.api import API
from z8ter.requests import Request
from z8ter.responses import JSONResponse


class [[ class_name ]](API):
    @API.endpoint("GET", "/")
    async def get_[[ api_name_lower ]](self, request: Request) -> JSONResponse:
        return JSONResponse({"ok": True, "message": "Hello from [[ class_name ]] API!"}, status_code=200)
