<!DOCTYPE html>
<html lang="en" data-theme="luxury">
  <head>
    <meta charset="UTF-8" />
    <title>Z8ter</title>
    <!-- Favicon configuration -->
    <link
      rel="icon"
      href="{{ url_for('static', filename='favicon/favicon.ico') }}"
    />
    <meta name="theme-color" content="#ffffff" />
    <meta name="viewport" content="width=device-width, initial-scale=1.0" />
    <link
      href="https://fonts.googleapis.com/css2?family=Inter:wght@400;600&display=swap"
      rel="stylesheet"
    />
    <link
      href="{{ url_for('static', filename='css/output.css') }}"
      rel="stylesheet"
    />
    <style>
      body {
        font-family: "Inter", sans-serif;
      }
    </style>
  </head>
  <body class="bg-base-100 text-base-content" data-page="{{ page_id|default('default') }}">
  {% from "macros/general.jinja" import Header, Footer %}
    {{ Header() }}
    <main class="flex-1 max-w-4xl mx-auto px-6 pt-24 pb-24 w-full">
      {% block content %}{% endblock %}
    </main>
    {{ Footer() }}
    {{ vite_script_tag("src/ts/app.ts") }}
  </body>
</html>
